#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-stylish-haskell-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-stylish-haskell-plugin-2.3.0.0-JTI0MA02HSa6NSaYNghtRt
key:                  hls-stylish-haskell-plugin-2.3.0.0-JTI0MA02HSa6NSaYNghtRt
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  5d8b9305c4c1b3662a3a4ff758e892e2
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-stylish-haskell-plugin-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-stylish-haskell-plugin-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-stylish-haskell-plugin-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-2.3.0.0-JTI0MA02HSa6NSaYNghtRt
depends:
    base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1 ghc-9.6.6
    ghc-boot-th-9.6.6 ghcide-2.3.0.0-EDsi359Zelb3bs0aS3Netj
    hls-plugin-api-2.3.0.0-AcIoZlqPhQDHyGB3lRYzhI
    lsp-types-2.0.2.0-Bxi9oxuHoFMD4IQOe0APCo mtl-2.3.1
    stylish-haskell-0.14.5.0-BUwHjaGSXf97B2gPmXjtqU text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

